package com.ruoyi.iit.service;

import com.ruoyi.iit.domain.IitPushUserRel;

import java.util.List;

/**
 * 消息管理Service接口
 *
 * @author Hao Li
 * @date 2025-04-11
 */
public interface IIitPushUserRelService {
    /**
     * 查询消息管理
     *
     * @param id 消息管理主键
     * @return 消息管理
     */
    public IitPushUserRel selectIitPushUserRelById(Long id);

    /**
     * 查询消息管理列表
     *
     * @param iitPushUserRel 消息管理
     * @return 消息管理集合
     */
    public List<IitPushUserRel> selectIitPushUserRelList(IitPushUserRel iitPushUserRel);

    /**
     * 新增消息管理
     *
     * @param iitPushUserRel 消息管理
     * @return 结果
     */
    public int insertIitPushUserRel(IitPushUserRel iitPushUserRel);

    /**
     * 修改消息管理
     *
     * @param iitPushUserRel 消息管理
     * @return 结果
     */
    public int updateIitPushUserRel(IitPushUserRel iitPushUserRel);

    /**
     * 批量删除消息管理
     *
     * @param ids 需要删除的消息管理主键集合
     * @return 结果
     */
    public int deleteIitPushUserRelByIds(Long[] ids);

    /**
     * 删除消息管理信息
     *
     * @param id 消息管理主键
     * @return 结果
     */
    public int deleteIitPushUserRelById(Long id);

    /**
     * 页面菜单消息管理列表
     * @param iitPushUserRel
     * @return
     */
    public List<IitPushUserRel> selectIitPushUserRelListV2(IitPushUserRel iitPushUserRel);

    /**
     * 获取详情，更新已读状态
     * @param id
     * @return
     */
    public IitPushUserRel getMessageInfo(Long id);
}
